==> htmlunit-2.19-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/html/HTMLTableHeaderCellElement.java <==
/*
 * Copyright (c) 2002-2015 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.html;

import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.EDGE;
import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.IE;

import com.gargoylesoftware.htmlunit.html.HtmlTableHeaderCell;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;
import com.gargoylesoftware.htmlunit.javascript.configuration.WebBrowser;

/**
 * The JavaScript object {@code HTMLTableHeaderCellElement}.
 *
 * @author Frank Danek
 */
@JsxClass(domClass = HtmlTableHeaderCell.class, browsers = { @WebBrowser(value = IE, minVersion = 11),
        @WebBrowser(EDGE) })
public class HTMLTableHeaderCellElement extends HTMLTableCellElement {

    /**
     * Default constructor.
     */
    @JsxConstructor(@WebBrowser(EDGE))
    public HTMLTableHeaderCellElement() {
    }
}

==> htmlunit-2.21-sources.jar: com/gargoylesoftware/htmlunit/javascript/host/html/HTMLTableHeaderCellElement.java <==
/*
 * Copyright (c) 2002-2016 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.gargoylesoftware.htmlunit.javascript.host.html;

import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.EDGE;
import static com.gargoylesoftware.htmlunit.javascript.configuration.BrowserName.IE;

import com.gargoylesoftware.htmlunit.html.HtmlTableHeaderCell;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxClass;
import com.gargoylesoftware.htmlunit.javascript.configuration.JsxConstructor;
import com.gargoylesoftware.htmlunit.javascript.configuration.WebBrowser;

/**
 * The JavaScript object {@code HTMLTableHeaderCellElement}.
 *
 * @author Frank Danek
 */
@JsxClass(domClass = HtmlTableHeaderCell.class, browsers = { @WebBrowser(IE),
        @WebBrowser(EDGE) })
public class HTMLTableHeaderCellElement extends HTMLTableCellElement {

    /**
     * Default constructor.
     */
    @JsxConstructor(@WebBrowser(EDGE))
    public HTMLTableHeaderCellElement() {
    }
}
